//******************************************************************************
//  Copyright (c) 2014-2022 by Željan Rikalo
//
//  See the included file COPYING.TXT for details about the copyright.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//******************************************************************************

#include "qpixmapcache_c.h"

void QPixmapCache_Clear()
{
  QPixmapCache::clear();
}
